pytilities.test.event.decorators.BDispatcher

Package pytilities :: Package test :: Package event :: Module decorators :: Class BDispatcher |
[hide private]
[frames] | no frames]

# Class BDispatcher

source code

                                         object --+
                                                  |
    attributecollectionbase.AttributeCollectionBase --+
                                                      |
                                            ADispatcher --+
                                                          |
                                                         BDispatcher

Instance Methods | [hide private]
__init__(self, arg) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `ADispatcher`: `dispatch_a`, `dispatch_b` Inherited from `attributecollectionbase.AttributeCollectionBase`: `__abs__`, `__add__`, `__copy__`, `__delattr__`, `__div__`, `__eq__`, `__floordiv__`, `__getattr__`, `__getitem__`, `__iadd__`, `__imul__`, `__iter__`, `__len__`, `__mul__`, `__neg__`, `__neq__`, `__nonzero__`, `__pos__`, `__rdiv__`, `__rfloordiv__`, `__rmul__`, `__rtruediv__`, `__setattr__`, `__setitem__`, `__str__`, `__sub__`, `__truediv__` Inherited from `attributecollectionbase.AttributeCollectionBase` (private): `_append_attribute_collection` Inherited from `object`: `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, arg) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)